
#include "timerpwm.h"
TimerPWM *timer2;
TimerPWM *timer3;
TimerPWM *timer4;

float periode_pwm = 100; // microsecondes

// bras de pont phase A
#define INA_1 2 // transistor haut
#define INA_2 3 // transistor bas
// bras de pont phase B
#define INB_1 5 
#define INB_2 7 
// bras de pont phase C
#define INC_1 9 
#define INC_2 8 

// états d'un bras de pont
#define HIGH_0_LOW_1 0 // sortie à la masse (état 01)
#define HIGH_1_LOW_0 1 // sortie en PWM (état 10)
#define HIGH_0_LOW_0 2 // sortie non connectée (état 00)

uint8_t sequence_A[6] = {1,1,2,0,0,2};
uint8_t sequence_B[6] = {0,2,1,1,2,0};
uint8_t sequence_C[6] = {2,0,0,2,1,1};

uint8_t is = 0;



void etat_bras_A(uint8_t etat) {
  switch (etat) {
    case HIGH_0_LOW_1:
      TIM2->CCR3 = 0;
      TIM2->CCR4 = 0;
      break;
    case HIGH_1_LOW_0:
      TIM2->CCR3 = timer2->ccr3;
      TIM2->CCR4 = timer2->ccr4;
      break;
    case HIGH_0_LOW_0:
      TIM2->CCR3 = 0;
      TIM2->CCR4 = timer2->arr + 1;
      break;
  }
}

void etat_bras_B(uint8_t etat) {
  switch (etat) {
    case HIGH_0_LOW_1:
      TIM3->CCR1 = 0;
      TIM3->CCR2 = 0;
      break;
    case HIGH_1_LOW_0:
      TIM3->CCR1 = timer3->ccr1;
      TIM3->CCR2 = timer3->ccr2;
      break;
    case HIGH_0_LOW_0:
      TIM3->CCR1 = 0;
      TIM3->CCR2 = timer2->arr + 1;
      break;
  }
}

void etat_bras_C(uint8_t etat) {
  switch (etat) {
    case HIGH_0_LOW_1:
      TIM4->CCR3 = 0;
      TIM4->CCR4 = 0;
      break;
    case HIGH_1_LOW_0:
      TIM4->CCR3 = timer4->ccr3;
      TIM4->CCR4 = timer4->ccr4;
      break;
    case HIGH_0_LOW_0:
      TIM4->CCR3 = 0;
      TIM4->CCR4 = timer4->arr + 1;
      break;
  }
}

void setup() {
  pinMode(INA_1,OUTPUT);
  digitalWrite(INA_1,LOW);
  pinMode(INA_2,OUTPUT);
  digitalWrite(INA_2,LOW);
  pinMode(INB_1,OUTPUT);
  digitalWrite(INB_1,LOW);
  pinMode(INB_2,OUTPUT);
  digitalWrite(INB_2,LOW);
  pinMode(INC_1,OUTPUT);
  digitalWrite(INC_1,LOW);
  pinMode(INC_2,OUTPUT);
  digitalWrite(INC_2,LOW);
  Serial.begin(115200);
  float r = 0.5;
  float temps_mort = 0.005; // 1/200 de période = 0,5 microsecondes
  float duty[2];
  duty[0] = r-temps_mort;
  duty[1] = r+temps_mort;
  bool invert[2] = {false,true};
  timer2 = new TimerPWM(2,2,periode_pwm,duty,invert,false,true,0);
  timer3 = new TimerPWM(3,2,periode_pwm,duty,invert,false,true,0);
  timer4 = new TimerPWM(4,2,periode_pwm,duty,invert,false,true,0);
  timer2->start();
  timer3->start();
  timer4->start();
}

void loop() {
  delay(1);
  etat_bras_A(sequence_A[is]);
  etat_bras_B(sequence_B[is]);
  etat_bras_C(sequence_C[is]);
  is += 1;
  if (is==6) is=0;
}

                     